import javax.swing.*;
import java.awt.*;

/**
 *  Demonstration application for DEM model objects.
 *  When this application is run, it may be necessary to increase
 * the amount of memory the JAVA engine is allowed to allocate.
 * use the run switch -Xmx256000000  to do this.
 *
 *  java -Xmx256000000 Main
 *
 * @author  Mark Pendergast
 * @version 1.0 February 2003
  */
class Main extends JFrame
{
   private View3DPanel viewPane = new View3DPanel();
   private InstructionPanel instructionPanel = new InstructionPanel();
   private ElevationModel model;
   //
   // Create a simple scene and attach it to the virtual universe
  //
    public Main()
    {
  //
  // setup the frame
  //
	setSize(800,600);
	setTitle("Demonstration of DEM Elevation data");
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE); // exit the program when this frame is closed
	getContentPane().add("South",instructionPanel);
	getContentPane().add("Center",viewPane);
}
/**
*  Loads elevation data file specified in first entry the cmdLine argument
*  if there is no command line then display a filedialog to allow the user to
* choose the file.
*  @param cmdLine command line from the main method
*/
public void load(String cmdLine[])
{
 String fileName;
//
//  load a dem file from the command line or pop up a file dialog
//
   viewPane.setRendering(false);
   if(cmdLine.length <= 0)  // file name on command line?
   {
   FileDialog dialog = new FileDialog(this, "Open Dem File",FileDialog.LOAD);  // create a filedialog object for reading
   dialog.setDirectory("." );
   dialog.setVisible(true);      // set the dialog to be visible

   if(dialog.getFile() == null) // did the user select a file
      System.exit(0); // no, just exit

   fileName = dialog.getDirectory()+dialog.getFile(); // create a full file name
  }
  else
     fileName = cmdLine[0];
//
// create a status window to allow progress to be displayed
//
   setCursor(new Cursor(Cursor.WAIT_CURSOR));
   StatusWindow stat = new StatusWindow(this);
   stat.setLocation((getWidth()-stat.getWidth())/2,(getHeight()-stat.getHeight())/2);
   stat.setVisible(true);
   try{
	  stat.setLabel1(fileName);
      viewPane.load(fileName,stat);
  }
 catch(IllegalArgumentException e)
   {
       JOptionPane.showMessageDialog(this,e.getMessage(),
         "Dem file load error",JOptionPane.ERROR_MESSAGE);  // popup an error message
       System.exit(0);
   }
   stat.dispose();
   setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
   setTitle("Digital Elevation Data for : "+viewPane.getModel().name);
   viewPane.setRendering(true);
}
/**
*  main routine, create the frame, make it visible, then attempt to load
* a file either from the command line (if present) or a dialog.
*/
public static void main(String cmdLine[])
{
 Main m = new Main();
 m.setVisible(true);
 m.load(cmdLine);
}

}
