import javax.swing.*;
import java.awt.*;

import com.sun.j3d.utils.universe.*;
import javax.media.j3d.*;
import javax.vecmath.*;
/**
 *  This class, based on JPanel, creates a Panel that displays a
 *  SimpleUniverse, complete with ambient and directional lights.
 *  View3DPanel also provides the capability to load and display
 *  DEM data, and view the data using a FlyingPlatform.
 *
 * @author  Mark Pendergast
 * @version 1.0 February 2003
 *
 */
public class View3DPanel extends JPanel
{
  /** degrees in the field of view */
   private static final int FIELD_OF_VIEW = 45;
  /** background color */
   private Color3f backgroundColor = new Color3f(0.0f,0.0f,0.8f);
  /** ambient light color */
   private Color3f ambientColor = new Color3f(.2f,.2f,.2f);
  /** directional light color */
   private Color3f directionalColor = new Color3f(1f,1f,1f);

   private SimpleUniverse universe = null;
   private Canvas3D canvas = null;
   private ElevationModel model = null;
   private FlyingPlatform platform = null;
   private BranchGroup world = null;
   private BoundingSphere	infiniteBounds = new BoundingSphere(new Point3d(), Double.MAX_VALUE);

  /**
   *
   *  This class, based on JPanel, creates a Panel that displays a
   *  SimpleUniverse complete with ambient and directional lights
   *
   */
   public View3DPanel()
   {
//
// add a Canvas to the center of the panel
//
	setLayout(new BorderLayout());
    GraphicsConfiguration config =
       SimpleUniverse.getPreferredConfiguration();
    canvas = new Canvas3D(config);
    canvas.stopRenderer();
    add("Center", canvas);

//
// Create the branch group to hold the world
//
    world  =    new BranchGroup();
    world.setCapability(Group.ALLOW_CHILDREN_EXTEND);
 //
 // Create the background
 //
      Background bg = new Background(backgroundColor);
      bg.setApplicationBounds(infiniteBounds);
      world.addChild(bg);
   //
   // create lights
   //
      BranchGroup lights = new BranchGroup();
      // Create the ambient light
      AmbientLight ambLight = new AmbientLight(true,ambientColor);
      ambLight.setInfluencingBounds(infiniteBounds);
      ambLight.setCapability(Light.ALLOW_STATE_WRITE);
      ambLight.setEnable(true);
      lights.addChild(ambLight);

      // Create the directional lights
       Vector3f dir = new Vector3f(1,-1,1);
       DirectionalLight dirLight = new DirectionalLight(true,directionalColor, dir);
      dirLight.setCapability(Light.ALLOW_INFLUENCING_BOUNDS_WRITE);
      dirLight.setCapability(Light.ALLOW_STATE_WRITE);
      dirLight.setInfluencingBounds(infiniteBounds);
      dirLight.setEnable(true);
      lights.addChild(dirLight);
       world.addChild(lights);
    //
   	// Create a universe and attach the branch group
   	//
   	universe = new SimpleUniverse(canvas);
    universe.addBranchGraph(world);
   }
  /**
  *  Loads elevation data file, creates and initializes the view
  * and viewing platform to conform to the terrain model
  */
  public void load(String fileName,StatusWindow stat)
  {
    model = new ElevationModel(fileName,stat);
    world.addChild(model);
   //
   //  Adjust the view based on the size of the model
   //
    View view = universe.getViewer().getView();
    view.setFrontClipDistance(1);  // allow user to get close to objects
    view.setBackClipDistance(model.getModelLength()*2);  // allow user to see far off objects
    view.setFieldOfView(Math.toRadians(FIELD_OF_VIEW));
    //
    //  setup the viewing platform.
    //
    platform = new FlyingPlatform(canvas, model);
    platform.setSchedulingBounds(infiniteBounds);
    universe.getViewingPlatform().setViewPlatformBehavior(platform);
    platform.goHome();

 }
 /**
  *  retrieve the elevation model that was last loaded.
  *  @return reference to ElevationModel object last loaded or null
  *    if a model has never been loaded.
  */
    public ElevationModel getModel()
    {
	  return model;
   }
  /**
   * starts and stops rendering
   * @param value if true, then start rendering, else stop rendering
   */
   public void setRendering(boolean value)
   {
	  if(value)
	    canvas.startRenderer();
	  else
	    canvas.stopRenderer();
  }
}